Package 'adbcsqlite'

Title: 'Arrow' Database Connectivity ('ADBC') 'SQLite' Driver
Description: Provides a developer-facing interface to the 'Arrow' Database Connectivity ('ADBC') 'SQLite' driver for the purposes of building high-level database interfaces for users. 'ADBC' <https://arrow.apache.org/adbc/> is an API standard for database access libraries that uses 'Arrow' for result sets and query parameters.
Authors: Dewey Dunnington [aut, cre] (ORCID: <https://orcid.org/0000-0002-9415-4582>), Apache Arrow [aut, cph], Apache Software Foundation [cph]
Maintainer: Dewey Dunnington <[email protected]>
License: Apache License (>= 2)
Version: 0.23.0.9000
Built: 2026-07-21 04:58:05 UTC
Source: https://github.com/apache/arrow-adbc

Help Index


ADBC SQLite3 Driver

Description

ADBC SQLite3 Driver

Usage

adbcsqlite()

## S3 method for class 'adbcsqlite_driver_sqlite'
adbc_database_init(driver, ..., uri = ":memory:")

## S3 method for class 'adbcsqlite_database'
adbc_connection_init(database, ..., adbc.connection.autocommit = NULL)

## S3 method for class 'adbcsqlite_connection'
adbc_statement_init(
  connection,
  ...,
  adbc.ingest.target_table = NULL,
  adbc.ingest.target_catalog = NULL,
  adbc.ingest.mode = NULL,
  adbc.sqlite.query.batch_rows = NULL
)

Arguments

driver

The driver to use. This can be one of the following:

  • A non-missing character(1) containing a driver or manifest name, a relative or absolute path to a driver or manifest, or a URI. For a URI, the driver manager uses the URI scheme as the driver name and passes the URI to that driver. A ⁠profile://⁠ URI loads a connection profile.

  • NULL, which leaves driver selection to the driver manager. In this case, ... must normally contain uri or profile; the driver is inferred from the URI or loaded from the connection profile.

  • An object that inherits from the adbc_driver class, such as one created by adbc_driver(). This includes drivers provided by R packages, such as adbcsqlite::adbcsqlite().

...

Driver-specific options. These are generally named values that are converted to strings.

uri

A URI to a database path or ":memory:" for an in-memory database.

database

An adbc_database.

adbc.connection.autocommit

Use FALSE to disable the default autocommit behaviour.

connection

An adbc_connection

adbc.ingest.target_table

The name of the target table for a bulk insert.

adbc.ingest.target_catalog

The catalog of the table for a bulk insert.

adbc.ingest.mode

Whether to create (the default) or append.

adbc.sqlite.query.batch_rows

The number of rows per batch to return.

Value

An adbcdrivermanager::adbc_driver()

Examples

adbcsqlite()